@@ -11,44 +11,44 @@
 #'
 #' @examples
 #' \dontrun{
-#' sess <- tf$Session()
 #'
-#' x <- tf$constant(1:15, shape = c(3, 5))
-#' sess$run(x)
-#' # by default, numerics supplied to `...` are interpreted R style
-#' sess$run( x[,1] )# first column
-#' sess$run( x[1:2,] ) # first two rows
-#' sess$run( x[,1, drop = FALSE] )
+#' x <- as_tensor(array(1:15, dim = c(3, 5)))
+#' x
+#' # by default, numerics supplied to [...] are interpreted R style
+#' x[,1]    # first column
+#' x[1:2,]  # first two rows
+#' x[,1, drop = FALSE] # 1 column matrix
 #'
 #' # strided steps can be specified in R syntax or python syntax
-#' sess$run( x[, seq(1, 5, by = 2)] )
-#' sess$run( x[, 1:5:2] )
+#' x[, seq(1, 5, by = 2)]
+#' x[, 1:5:2]
 #' # if you are unfamiliar with python-style strided steps, see:
-#' # https://docs.scipy.org/doc/numpy-1.13.0/reference/arrays.indexing.html#basic-slicing-and-indexing
+#' # https://numpy.org/doc/stable/reference/arrays.indexing.html#basic-slicing-and-indexing
 #'
 #' # missing arguments for python syntax are valid, but they must by backticked
 #' # or supplied as NULL
-#' sess$run( x[, `::2`] )
-#' sess$run( x[, NULL:NULL:2] )
-#' sess$run( x[, `2:`] )
+#' x[, `::2`]
+#' x[, NULL:NULL:2]
+#' x[, `2:`]
 #'
-#' # Another python feature that is available is a python style ellipsis `...`
+#'
+#' # all_dims() expands to the shape of the tensor
+#' # (equivalent to a python ellipsis `...`)
 #' # (not to be confused with R dots `...`)
-#' # a all_dims() expands to the shape of the tensor
-#' y <- tf$constant(1:(3^5), shape = c(3,3,3,3,3))
-#' identical(
-#'   sess$run( y[all_dims(), 1] ),
-#'   sess$run( y[,,,,1] )
-#'   )
+#' y <- as_tensor(array(1:(3^5), dim = c(3,3,3,3,3)))
+#' all.equal(y[all_dims(), 1],
+#'           y[, , , , 1])
+#'
+#' # tf$newaxis are valid (equivalent to a NULL)
+#' x[,, tf$newaxis]
+#' x[,, NULL]
 #'
-#' # tf$newaxis are valid
-#' sess$run( x[,, tf$newaxis] )
 #'
 #' # negative numbers are always interpreted python style
 #' # The first time a negative number is supplied to `[`, a warning is issued
 #' # about the non-standard behavior.
-#' sess$run( x[-1,] ) # last row, with a warning
-#' sess$run( x[-1,] )# the warning is only issued once
+#' x[-1,]  # last row, with a warning
+#' x[-1,]  # the warning is only issued once
 #'
 #' # specifying `style = 'python'` changes the following:
 #' # +  zero-based indexing is used
@@ -60,22 +60,22 @@
 #' # as a global option
 #'
 #' # example of zero based  indexing
-#' sess$run( x[0, , style = 'python'] ) # first row
-#' sess$run( x[1, , style = 'python'] ) # second row
+#' x[0, , style = 'python']  # first row
+#' x[1, , style = 'python']  # second row
 #'
 #' # example of slices with exclusive stop
 #' options(tensorflow.extract.style = 'python')
-#' sess$run( x[, 0:1] ) # just the first column
-#' sess$run( x[, 0:2] ) # first and second column
+#' x[, 0:1]  # just the first column
+#' x[, 0:2]  # first and second column
 #'
 #' # example of out-of-bounds index
-#' sess$run( x[, 0:10] )
+#' x[, 0:10]
 #' options(tensorflow.extract.style = NULL)
 #'
 #' # slicing with tensors is valid too, but note, tensors are never
 #' # translated and are always interpreted python-style.
 #' # A warning is issued the first time a tensor is passed to `[`
-#' sess$run( x[, tf$constant(0L):tf$constant(2L)] )
+#' x[, tf$constant(0L):tf$constant(2L)]
 #' # just as in python, only scalar tensors are valid
 #' # https://www.tensorflow.org/api_docs/python/tf/Tensor#__getitem__
 #'
@@ -511,11 +511,11 @@ warn_if_any_negative <- function(dots) {
     ignore_py_slice_step = TRUE,
     if_any_TRUE = {
       warning( call. = FALSE,
-        "Negative numbers are interpreted python-style when subsetting tensorflow tensors.",
-        "(they select items by counting from the back). For more details, see: ",
-        "https://docs.scipy.org/doc/numpy-1.13.0/reference/arrays.indexing.html#basic-slicing-and-indexing\n",
-        "To turn off this warning, set ",
-        "'options(tensorflow.extract.warn_negatives_pythonic = FALSE)'")
+        "Negative numbers are interpreted python-style when subsetting tensorflow tensors." ,
+        " (they select items by counting from the back). For more details, see:",
+        "\n\thttps://numpy.org/doc/stable/reference/arrays.indexing.html#basic-slicing-and-indexing",
+        "\nTo turn off this warning, set",
+        " 'options(tensorflow.extract.warn_negatives_pythonic = FALSE)'")
       warned_about$negative_indices <- TRUE
     })
 }
